changeset 13876:c511ca6f1594 draft

(svn r18405) -Fix (r18405): RVs didn't like to stop when the 'next' drive through station tile didn't have a compatible road type
author rubidium <rubidium@openttd.org>
date Fri, 04 Dec 2009 21:01:28 +0000
parents 052c69fbc76b
children 798f34f56934
files src/roadveh_cmd.cpp
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/roadveh_cmd.cpp
+++ b/src/roadveh_cmd.cpp
@@ -1470,8 +1470,8 @@
 			if (IsDriveThroughStopTile(v->tile)) {
 				TileIndex next_tile = TILE_ADD(v->tile, TileOffsByDir(v->direction));
 
-				/* Check if next inline bay is free */
-				if (RoadStop::IsDriveThroughRoadStopContinuation(v->tile, next_tile)) {
+				/* Check if next inline bay is free and has compatible road. */
+				if (RoadStop::IsDriveThroughRoadStopContinuation(v->tile, next_tile) && (GetRoadTypes(next_tile) & v->compatible_roadtypes) != 0) {
 					v->frame++;
 					RoadZPosAffectSpeed(v, SetRoadVehPosition(v, x, y, false));
 					return true;